==> quasar-1.2.3.tgz: package/icon-set/ionicons-v4.js <==
export default {
  name: 'ionicons-v4',
  type: {
    positive: 'ion-md-checkmark',
    negative: 'ion-alert',
    info: 'ion-information-circle-outline',
    warning: 'ion-alert'
  },
  arrow: {
    up: 'ion-arrow-up',
    right: 'ion-arrow-forward',
    down: 'ion-arrow-down',
    left: 'ion-arrow-back',
    dropdown: 'ion-arrow-dropdown'
  },
  chevron: {
    left: 'ion-ios-arrow-back',
    right: 'ion-ios-arrow-forward'
  },
  colorPicker: {
    spectrum: 'ion-aperture',
    tune: 'ion-options',
    palette: 'ion-apps'
  },
  pullToRefresh: {
    icon: 'ion-refresh'
  },
  carousel: {
    left: 'ion-ios-arrow-back',
    right: 'ion-ios-arrow-forward',
    navigationIcon: 'ion-square',
    thumbnails: 'ion-grid'
  },
  chip: {
    remove: 'ion-close-circle',
    selected: 'ion-checkmark'
  },
  datetime: {
    arrowLeft: 'ion-ios-arrow-back',
    arrowRight: 'ion-ios-arrow-forward',
    now: 'ion-time',
    today: 'ion-calendar'
  },
  editor: { // requires Material icons for some as Ionicons simply does not have everything needed
    bold: 'format_bold',
    italic: 'format_italic',
    strikethrough: 'strikethrough_s',
    underline: 'format_underlined',
    unorderedList: 'format_list_bulleted',
    orderedList: 'format_list_numbered',
    subscript: 'vertical_align_bottom',
    superscript: 'vertical_align_top',
    hyperlink: 'ion-link',
    toggleFullscreen: 'ion-expand',
    quote: 'ion-quote',
    left: 'format_align_left',
    center: 'format_align_center',
    right: 'format_align_right',
    justify: 'format_align_justify',
    print: 'ion-print',
    outdent: 'format_indent_decrease',
    indent: 'format_indent_increase',
    removeFormat: 'format_clear',
    formatting: 'text_format',
    fontSize: 'format_size',
    align: 'format_align_left',
    hr: 'remove',
    undo: 'ion-undo',
    redo: 'ion-redo',
    header: 'format_size',
    code: 'ion-code',
    size: 'format_size',
    font: 'font_download',
    viewSource: 'ion-ios-code'
  },
  expansionItem: {
    icon: 'ion-arrow-dropdown',
    denseIcon: 'ion-arrow-dropdown'
  },
  fab: {
    icon: 'ion-add',
    activeIcon: 'ion-close'
  },
  field: {
    clear: 'ion-close-circle',
    error: 'ion-alert'
  },
  pagination: {
    first: 'ion-skip-backward',
    prev: 'ion-arrow-back',
    next: 'ion-arrow-forward',
    last: 'ion-skip-forward'
  },
  rating: {
    icon: 'ion-star'
  },
  stepper: {
    done: 'ion-checkmark',
    active: 'ion-create',
    error: 'ion-warning'
  },
  tabs: {
    left: 'ion-ios-arrow-back',
    right: 'ion-ios-arrow-forward',
    up: 'ion-ios-arrow-up',
    down: 'ion-ios-arrow-down'
  },
  table: {
    arrowUp: 'ion-arrow-up',
    warning: 'ion-warning',
    prevPage: 'ion-ios-arrow-back',
    nextPage: 'ion-ios-arrow-forward'
  },
  tree: {
    icon: 'ion-play'
  },
  uploader: {
    done: 'ion-checkmark',
    clear: 'ion-close',
    add: 'ion-add-circle',
    upload: 'ion-cloud-upload',
    removeQueue: 'ion-trash',
    removeUploaded: 'ion-done-all'
  }
}

==> quasar-1.7.3.tgz: package/icon-set/ionicons-v4.js <==
export default {
  name: 'ionicons-v4',
  type: {
    positive: 'ion-md-checkmark',
    negative: 'ion-alert',
    info: 'ion-information-circle-outline',
    warning: 'ion-alert'
  },
  arrow: {
    up: 'ion-arrow-up',
    right: 'ion-arrow-forward',
    down: 'ion-arrow-down',
    left: 'ion-arrow-back',
    dropdown: 'ion-arrow-dropdown'
  },
  chevron: {
    left: 'ion-ios-arrow-back',
    right: 'ion-ios-arrow-forward'
  },
  colorPicker: {
    spectrum: 'ion-aperture',
    tune: 'ion-options',
    palette: 'ion-apps'
  },
  pullToRefresh: {
    icon: 'ion-refresh'
  },
  carousel: {
    left: 'ion-ios-arrow-back',
    right: 'ion-ios-arrow-forward',
    navigationIcon: 'ion-square',
    thumbnails: 'ion-grid'
  },
  chip: {
    remove: 'ion-close-circle',
    selected: 'ion-checkmark'
  },
  datetime: {
    arrowLeft: 'ion-ios-arrow-back',
    arrowRight: 'ion-ios-arrow-forward',
    now: 'ion-time',
    today: 'ion-calendar'
  },
  editor: { // requires Material icons for some as Ionicons simply does not have everything needed
    bold: 'format_bold',
    italic: 'format_italic',
    strikethrough: 'strikethrough_s',
    underline: 'format_underlined',
    unorderedList: 'format_list_bulleted',
    orderedList: 'format_list_numbered',
    subscript: 'vertical_align_bottom',
    superscript: 'vertical_align_top',
    hyperlink: 'ion-link',
    toggleFullscreen: 'ion-expand',
    quote: 'ion-quote',
    left: 'format_align_left',
    center: 'format_align_center',
    right: 'format_align_right',
    justify: 'format_align_justify',
    print: 'ion-print',
    outdent: 'format_indent_decrease',
    indent: 'format_indent_increase',
    removeFormat: 'format_clear',
    formatting: 'text_format',
    fontSize: 'format_size',
    align: 'format_align_left',
    hr: 'remove',
    undo: 'ion-undo',
    redo: 'ion-redo',
    heading: 'format_size',
    code: 'ion-code',
    size: 'format_size',
    font: 'font_download',
    viewSource: 'ion-ios-code'
  },
  expansionItem: {
    icon: 'ion-arrow-dropdown',
    denseIcon: 'ion-arrow-dropdown'
  },
  fab: {
    icon: 'ion-add',
    activeIcon: 'ion-close'
  },
  field: {
    clear: 'ion-close-circle',
    error: 'ion-alert'
  },
  pagination: {
    first: 'ion-skip-backward',
    prev: 'ion-arrow-back',
    next: 'ion-arrow-forward',
    last: 'ion-skip-forward'
  },
  rating: {
    icon: 'ion-star'
  },
  stepper: {
    done: 'ion-checkmark',
    active: 'ion-create',
    error: 'ion-warning'
  },
  tabs: {
    left: 'ion-ios-arrow-back',
    right: 'ion-ios-arrow-forward',
    up: 'ion-ios-arrow-up',
    down: 'ion-ios-arrow-down'
  },
  table: {
    arrowUp: 'ion-arrow-up',
    warning: 'ion-warning',
    prevPage: 'ion-ios-arrow-back',
    nextPage: 'ion-ios-arrow-forward'
  },
  tree: {
    icon: 'ion-play'
  },
  uploader: {
    done: 'ion-checkmark',
    clear: 'ion-close',
    add: 'ion-add-circle',
    upload: 'ion-cloud-upload',
    removeQueue: 'ion-trash',
    removeUploaded: 'ion-done-all'
  }
}
